odoo.define('percent_widget', function(require) {
    "use strict";

    // Require below taken from addons/web/static/src/js/fields,
    // https://github.com/odoo/odoo/tree/13.0/addons/web/static/src/js/widgets
    var fieldRegistry = require('web.field_registry');
	var field_utils = require('web.field_utils');
    var basic_fields = require('web.basic_fields');
    var InputField = basic_fields.InputField;
	var ModelFieldSelector = require("web.ModelFieldSelector");

    // Form View
    var PercentWidget = InputField.extend({
        className: 'o_field_percent o_field_number',
        tagName: 'span',
        supportedFieldTypes: ['float'],

        /**
         * In readonly, emails should be a link, not a span.
         *
         * @override
         */
        init: function () {
            this._super.apply(this, arguments);

           
            // default symbol
            this.symbol = "%";

            if (this.mode === 'edit') {
                this.tagName = 'div';
                this.className += ' o_input';
            } else {
                this.tagName = 'a';
            }
        },
        /**
         * Returns the associated link.
         *
         * @override
         */
        getFocusableElement: function () {
            return this.mode === 'readonly' ? this.$el : this._super.apply(this, arguments);
        },
        /**
         * In readonly, the widget needs to be a link with proper href and proper
         * support for the design, which is achieved by the added classes.
         *
         * @override
         */
        _renderReadonly: function () {
            this.$el.text(this._formatValue(this.value));
            this.$el.append($('<span>', {text: '\u00A0' + this.symbol}));
        },
        /**
         * Formats an input for edit mode.
         * @override
         */
        _renderEdit: function () {
            this.$el.empty();

            // Prepare and add the input
            this._prepareInput().appendTo(this.$el);

            var $percentSymbol = $('<span>', {text: this.symbol});
            this.$el.append($percentSymbol);
        },
        /**
         * Format percent value
         *
         * Note: We have to overwrite this method to convert value float in percent.
         * The idea is that we sometimes want to display something like 10% instead of 0.1.
         *
         * @override
         * @param {float} value
         * @returns {string}
         */
        _formatValue: function (value) {
            // do not accept not numbers
            if (isNaN(value)) {
                throw new Error(_.str.sprintf(core._t("'%s' is not a correct numbers"), value));
            }
			return field_utils.format.float(value * 100, this.field);
        },
        /**
         * Converts a string representation to a valid value.
         *
         * @override
         * @param {string} value
         * @returns {float}
         */
        _parseValue: function (value) {
			var parsed = field_utils.parse.float(value);

            // do not accept not numbers values
            if (isNaN(parsed)) {
                throw new Error(_.str.sprintf(core._t("'%s' is not a correct number"), value));
            }

            return (parsed / parseFloat(100));
        },

    });

    fieldRegistry.add('percent', PercentWidget);

});
